==> fred_prequel-0.2.3-py3-none-any.whl: prequel/info.py <==
"""Public request info service client."""
from typing import Dict, List, cast

from fred_api.public_request import service_public_request_info_grpc_pb2_grpc
from fred_api.public_request.common_types_pb2 import RegistryObjectType as RegistryObjectTypeMsg
from fred_api.public_request.service_public_request_info_grpc_pb2 import (
    GetRequest as GetRequestMsg,
    ListRequest as ListRequestMsg,
)
from frgal.aio import AsyncGrpcClient
from google.protobuf import empty_pb2

from .common import PublicRequest, PublicRequestId
from .decoder import PublicRequestDecoder


class PublicRequestInfoClient(AsyncGrpcClient):
    """Public request info service client."""

    service = "PublicRequestInfo"
    decoder_cls = PublicRequestDecoder
    grpc_modules = (service_public_request_info_grpc_pb2_grpc,)

    async def get_types(self) -> Dict[str, bool]:
        """Get types of available public requests with registry staff resolvable flag.

        Args:
            none

        Returns:
            supported public request types with assosiated staff resolvable flag

        Note: Return type enforces unique public request names (empty string allowed).
        """
        response = await self.call(self.service, "get_types", empty_pb2.Empty())
        result: Dict[str, bool] = {}
        if response:
            result = {i["name"]: i["is_resolvable"] for i in response}
        return result

    async def list(self, ref_type: str, ref_value: str) -> List[PublicRequest]:
        """List all public requests linked to the referenced object.

        Args:
            ref_type: Registry object type ("domain", ...).
            ref_value: Registry object identifier.

        Returns:
            List of public request items (possibly empty).

        Note: Results are sorted by their creation time (most recent first).
        """
        request = ListRequestMsg()
        request.registry_object_reference.type = RegistryObjectTypeMsg.Enum.Value(ref_type)
        request.registry_object_reference.value = ref_value
        result: List[PublicRequest] = []
        async for message in self.call_stream(self.service, "list", request):  # pragma: no cover
            if message:
                result.extend(message)
        return result

    async def get(self, public_request_id: PublicRequestId) -> PublicRequest:
        """Get public request by its identifier.

        Args:
            public_request_id: Public request identifier.

        Return:
            Public request information (when found).

        Raises:
            PublicRequestDoesNotExist (when not found).
        """
        request = GetRequestMsg()
        request.public_request_id.value = public_request_id
        return cast(PublicRequest, await self.call(self.service, "get", request))

==> fred_prequel-1.0.0-py3-none-any.whl: prequel/info.py <==
"""Public request info service client."""

from typing import Dict, List, cast

from fred_api.public_request.common_types_pb2 import RegistryObjectType as RegistryObjectTypeMsg
from fred_api.public_request.service_public_request_info_grpc_pb2 import (
    GetRequest as GetRequestMsg,
    ListRequest as ListRequestMsg,
)
from fred_api.public_request.service_public_request_info_grpc_pb2_grpc import PublicRequestInfoStub
from frgal.aio import AsyncGrpcClient
from google.protobuf import empty_pb2

from .common import PublicRequest, PublicRequestId
from .decoder import PublicRequestDecoder


class PublicRequestInfoClient(AsyncGrpcClient):
    """Public request info service client."""

    stub_cls = PublicRequestInfoStub
    decoder_cls = PublicRequestDecoder

    async def get_types(self) -> Dict[str, bool]:
        """Get types of available public requests with registry staff resolvable flag.

        Args:
            none

        Returns:
            supported public request types with assosiated staff resolvable flag

        Note: Return type enforces unique public request names (empty string allowed).
        """
        response = await self.call("get_types", empty_pb2.Empty())
        result: Dict[str, bool] = {}
        if response:
            result = {i["name"]: i["is_resolvable"] for i in response}
        return result

    async def list(self, ref_type: str, ref_value: str) -> List[PublicRequest]:
        """List all public requests linked to the referenced object.

        Args:
            ref_type: Registry object type ("domain", ...).
            ref_value: Registry object identifier.

        Returns:
            List of public request items (possibly empty).

        Note: Results are sorted by their creation time (most recent first).
        """
        request = ListRequestMsg()
        request.registry_object_reference.type = RegistryObjectTypeMsg.Enum.Value(ref_type)
        request.registry_object_reference.value = ref_value
        result: List[PublicRequest] = []
        async for message in self.call_stream("list", request):  # pragma: no cover
            if message:
                result.extend(message)
        return result

    async def get(self, public_request_id: PublicRequestId) -> PublicRequest:
        """Get public request by its identifier.

        Args:
            public_request_id: Public request identifier.

        Return:
            Public request information (when found).

        Raises:
            PublicRequestDoesNotExist (when not found).
        """
        request = GetRequestMsg()
        request.public_request_id.value = public_request_id
        return cast(PublicRequest, await self.call("get", request))
